Module timer

Module timer 

Structs

TaskStatus
Task status information structure.
Timer
Timer that generates periodic tick events at 1-second intervals.
WheelCascadeGuide
Guide for cascade positioning of tasks across multiple time wheels.

Enums

TimerEvent
Events generated by the timer system.
WheelType
Represents the type of wheel a task is currently in.