Structs
- Task
Status - Task status information structure.
- Timer
- Timer that generates periodic tick events at 1-second intervals.
- Wheel
Cascade Guide - Guide for cascade positioning of tasks across multiple time wheels.
Enums
- Timer
Event - Events generated by the timer system.
- Wheel
Type - Represents the type of wheel a task is currently in.