pub struct Timer { /* private fields */ }Expand description
Timer that generates periodic tick events at 1-second intervals.
The Timer is responsible for generating time-based events that drive the execution of scheduled tasks. It uses a Clock to generate ticks and sends TimerEvent::Tick events through a channel.
Implementations
Sourceimpl Timer
impl Timer
Sourcepub fn new(event_sender: Sender<TimerEvent>) -> Self
pub fn new(event_sender: Sender<TimerEvent>) -> Self
Sourcepub fn is_running(&self) -> bool
pub fn is_running(&self) -> bool